==> escapework-manager-0.4.0-9a43a3.tar: src/views/roles/form.blade.php <==
@extends('manager::layouts.master')

@section('content')
    <div class="page-header">
        <div class="pull-left">
            <h1>Perfis</h1>
        </div><!-- .pull-left --> 

        <div class="pull-right">
            <a href="{{ route('manager.roles.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div> 
    </div><!-- .page-header --> 

    {{ Msg::getAll() }}

    <form action="{{ !$edit ? route('manager.roles.store') : route('manager.roles.update', $role->id) }}" method="post" id="form-role" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            <div class="control-group">
                <label for="title" class="control-label">Título</label>

                <div class="controls">
                    <input type="text" name="title" id="title" class="input-xxlarge" value="{{ $role->title }}" autofocus />
                </div><!-- .controls --> 
            </div><!-- .control-group --> 

            <div class="control-group">
                <label class="control-label">Todas permissões liberadas?</label>

                <div class="controls">
                    <label class="inline radio">
                        <input type="radio" name="all_permissions" value="1" {{ $role->all_permissions ? 'checked="checked"' : null }} /> 
                        Sim 
                    </label>

                    <label class="inline radio">
                        <input type="radio" name="all_permissions" value="0" {{ !$role->all_permissions ? 'checked="checked"' : null }} /> 
                        Não 
                    </label>
                </div><!-- .controls --> 
            </div><!-- .control-group --> 
        </fieldset>

        <fieldset id="box-permissions" class="{{ $role->all_permissions ? 'hide' : '' }}">
            <legend>Páginas e Permissões</legend>

            @foreach ($pages as $page)
                <div class="control-group">
                    <label class="control-label">{{ $page->title }}</label>

                    <div class="controls js-controls-permissions">
                        <label class="checkbox">
                            <input type="checkbox" data-check-all="{{ $page->slug }}" /> 
                            <span class="label label-info">Marcar/Desmarcar todos</span>
                        </label>

                        @foreach ($page->actions as $action)
                            <label class="checkbox">
                                <input type="hidden" name="page[{{ $action->id }}]" value="{{ $action->page_id }}" />
                                <input type="checkbox" name="action[]" value="{{ $action->id }}" {{ $roleActions->contains($action->id) ? 'checked="checked"' : null }} data-page="{{ $page->slug }}" /> 
                                {{ $action->title }}
                            </label>
                        @endforeach
                    </div><!-- .controls --> 
                </div><!-- .control-group --> 
            @endforeach
        </fieldset>

        <div class="form-actions">
            <input type="submit" class="btn btn-primary" value="Salvar" /> 
            <a href="{{ route('manager.roles.index') }}" class="btn">Cancelar</a>
        </div><!-- .form-actions --> 
    </form>
@stop

@section('scripts')
    @parent
    
    <script type="text/javascript" src="/packages/escapework/manager/assets/js/roles/form.js"></script>
@stop

==> escapework-manager-0.8.0-9a300b.tar: src/views/roles/form.blade.php <==
@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li><a href="{{ route('manager.roles.index') }}">Perfis</a> <span class="divider">/</span></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Perfis</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.roles.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    {{ Msg::getAll() }}

    <form action="{{ !$edit ? route('manager.roles.store') : route('manager.roles.update', $role->id) }}" method="post" id="form-role" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            <div class="control-group">
                <label for="title" class="control-label">Título</label>

                <div class="controls">
                    <input type="text" name="title" id="title" class="input-xxlarge" value="{{ $role->title }}" autofocus />
                </div><!-- .controls -->
            </div><!-- .control-group -->

            <div class="control-group">
                <label class="control-label">Todas permissões liberadas?</label>

                <div class="controls">
                    <label class="inline radio">
                        <input type="radio" name="all_permissions" value="1" {{ $role->all_permissions ? 'checked="checked"' : null }} />
                        Sim
                    </label>

                    <label class="inline radio">
                        <input type="radio" name="all_permissions" value="0" {{ !$role->all_permissions ? 'checked="checked"' : null }} />
                        Não
                    </label>
                </div><!-- .controls -->
            </div><!-- .control-group -->
        </fieldset>

        <fieldset id="box-permissions" class="{{ $role->all_permissions ? 'hide' : '' }}">
            <legend>Páginas e Permissões</legend>

            @foreach ($pages as $page)
                <div class="control-group">
                    <label class="control-label">{{ $page->title }}</label>

                    <div class="controls js-controls-permissions">
                        <label class="checkbox">
                            <input type="checkbox" data-check-all="{{ $page->slug }}" />
                            <span class="label label-info">Marcar/Desmarcar todos</span>
                        </label>

                        @foreach ($page->actions as $action)
                            <label class="checkbox">
                                <input type="hidden" name="page[{{ $action->id }}]" value="{{ $action->page_id }}" />
                                <input type="checkbox" name="action[]" value="{{ $action->id }}" {{ $roleActions->contains($action->id) ? 'checked="checked"' : null }} data-page="{{ $page->slug }}" />
                                {{ $action->title }}
                            </label>
                        @endforeach
                    </div><!-- .controls -->
                </div><!-- .control-group -->
            @endforeach
        </fieldset>

        <div class="form-actions">
            <input type="submit" class="btn btn-primary js-btn-submit" value="Salvar" data-loading-text="Carregando..." />
            <a href="{{ route('manager.roles.index') }}" class="btn">Cancelar</a>
        </div><!-- .form-actions -->
    </form>
@stop

@section('scripts')
    @parent
    <script type="text/javascript" src="{{ asset('packages/escapework/manager/assets/js/roles/form.js') }}"></script>
@stop
